<template>
  <el-dialog
    :title="title"
    :visible.sync="dialogVisible"
    width="1300px"
    append-to-body
    top="5vh"
  >
    <div>
      <FormTemplate
        v-if="type === 'batchApplyCode'"
        type="add"
        :selfColumnType="selfColumnType"
        :selfColumnConfig="selfColumnConfig"
        ref="CodeApply"
        @getFormData="getCodeApplyFormData"
        @referConfigDataUpdate="referConfigDataUpdate"
      ></FormTemplate>
    </div>
    <div class="flex_box">
      <div class="left" :style="{ width: leftWidth + 'px' }">
        <div class="isExpand_box">
          <el-link type="primary" @click="hideTree">
            <i
              :class="isExpand ? 'el-icon-arrow-left' : 'el-icon-arrow-right'"
            ></i>
            {{ isExpand ? "收缩" : "展开" }}
          </el-link>
        </div>
        <el-input
          placeholder="输入关键字进行过滤"
          v-model="filterText"
          size="small"
          v-show="isExpand"
        >
        </el-input>
        <el-tree
          v-show="isExpand"
          class="filter_tree"
          :data="leftTree"
          default-expand-all
          highlight-current
          :filter-node-method="filterNode"
          @node-click="treeNodeClick"
          ref="tree"
          :props="{
            label: 'name',
          }"
        >
        </el-tree>
      </div>
      <div class="right" :style="{ width:  1280 - leftWidth - 60 + 'px' }">
        <div class="tab_box" style="width: 100%">
          <el-tabs
            style="width: 100%"
            v-model="activeTab"
            type="card"
            @tab-click="handleClick"
            size="small"
          >
            <el-tab-pane :label="tab1Name" name="tab1">
              <el-table
                border
                :data="tab1Table"
                style="width: 100%"
                height="400px"
                highlight-current-row
                @current-change="resembleRowChange"
                @selection-change="tab1TableSelectChange"
                v-if="cloNamesList.length > 1"
              >
              <el-table-column
                  type="selection"
                  width="100px"
                  align="center"
                ></el-table-column>
                <el-table-column
                  type="index"
                  label="序号"
                  width="100px"
                  align="center"
                ></el-table-column>
                <el-table-column
                  v-for="item in cloNamesList"
                  :key="item.field"
                  :prop="item.field"
                  :label="item.title"
                  :width="item.width"
                  align="center"
                >
                </el-table-column>
              </el-table>
              <div v-else style="height: 400px"></div>
            </el-tab-pane>
            <el-tab-pane :label="tab2Name" name="tab2">
              <el-table border :data="tab2Table" height="400px">
                <el-table-column
                  v-for="item in cloNamesList"
                  :key="item.field"
                  :prop="item.field"
                  :label="item.title"
                  :width="item.width"
                  align="center"
                >
                </el-table-column>
              </el-table>
            </el-tab-pane>
          </el-tabs>
        </div>
        <div>
          <el-table
            border
            :data="currentSelectedResemble"
            style="width: 100%"
            height="200px"
          >
            <el-table-column
              v-for="item in resembleColumList"
              :key="item.field"
              :prop="item.field"
              :label="item.title"
              :minWidth="item.minWidth"
              align="center"
            >
              <template #default="{ row }">
                <span v-if="item.field === 'id'">
                  <el-link type="primary" @click="openFormTemlpate(row)">{{
                    row[item.field]
                  }}</el-link>
                </span>
                <span v-else>
                  {{ row[item.field] }}
                </span>
              </template>
            </el-table-column>
            <el-table-column
              v-show="resembleColumList.length > 0"
              prop="rowIndex"
              label="excel行数"
              align="center"
            ></el-table-column>
          </el-table>
        </div>
      </div>
    </div>
    <template #footer>
      <div>
        <el-button size="small" type="primary" @click="submit"
          >确定导入</el-button
        >
        <el-button size="small" @click="dialogVisible = false">取消</el-button>
      </div>
    </template>
    <FormTemplateDialog
      ref="FormTemplateDialog"
      type="detail"
      v-bind="currentSelectedResembleRow"
      :visible.sync="currentSelectedResembleRow.visible"
      title="查看详细信息"
    ></FormTemplateDialog>
  </el-dialog>
</template>

<script>
import {
  getHistorySuccessTable,
  getHistoryResembleTable,
  getFormTemplate,
  getCurretnSelectedRowResemble,
  submitHistoryimport,
} from "../../api/batchImport/index";
import ResembleQuery from "../FormTemplate/ResembleQuery.vue";
import FormTemplate from "../FormTemplate/FormTemplate.vue";
import codeApply from "@/mixins/codeApply.js";

export default {
  name: "ShowImportData",
  components: { ResembleQuery, FormTemplate },
  mixins: [codeApply],
  props: {
    title: {
      type: String,
      default: "历史数据导入",
    },
    visible: false,
    leftTree: {
      type: Array,
      default: () => [],
    },
    redisOid: {
      type: String,
      default: "",
    },
    classifyAttr: {
      type: String,
      default: "id",
    },
    codeClassifyOid: {
      type: String,
      default: "",
    },
  },
  computed: {
    dialogVisible: {
      get() {
        return this.visible;
      },
      set(val) {
        this.$emit("update:visible", val);
      },
    },
  },
  data() {
    return {
      isExpand: true,
      filterText: "",
      leftWidth: "200",
      templateOid: null,
      tab1Name: "相似项",
      tab2Name: "正确数据",
      tab1Table: [],
      selectedTab1Table: [],
      tab2Table: [],
      activeTab: "tab1",
      cloNamesList: [], //列表头部字段
      localCodeClassifyOid: "",
      resembleColumList: [], //相似项查出来的列表字段
      currentSelectedResemble: [],
      currentSelectedResembleRow: {
        templateOid: "",
        codeClassifyOid: "",
        rowOid: "",
        formTemplateVisible: false,
      },
      secVOList: [],
    };
  },

  methods: {
    filterNode(value, data) {
      if (!value) return true;
      return data.name.indexOf(value) !== -1;
    },
    hideTree() {
      if (this.isExpand) {
        this.leftWidth = "50";
      } else {
        this.leftWidth = "200";
      }
      this.isExpand = !this.isExpand;
    },
    treeNodeClick(data) {
      console.log(data);
      this.localCodeClassifyOid = data.codeclassifyoid;
      this.cloNamesList = data.cloNamesList;
      this.templateOid = data.oid;
      getHistorySuccessTable({
        codeClassifyOid: this.templateOid,
        redisOid: this.redisOid + "-ok",
      }).then((res) => {
        this.tab2Table = res.data.data;
      });
      getHistoryResembleTable({
        codeClassifyOid: this.templateOid,
        redisOid: this.redisOid + "-resemble",
      }).then((res) => {
        this.tab1Table = res.data.data;
      });
      getFormTemplate({
        templateOid: data.oid,
        codeClassifyOid: this.localCodeClassifyOid,
      }).then((res) => {
        this.resembleColumList = res.data.resembleTableVO.cols[0];
      });
    },
    tab1TableSelectChange(selection) {
      this.selectedTab1Table = selection;
    },
    resembleRowChange(row) {
      getCurretnSelectedRowResemble({
        redisOid: this.redisOid + "-resemble-data",
        dataOid: row.oid,
      }).then((res) => {
        this.currentSelectedResemble = res.data.data;
      });
    },
    openFormTemlpate(row) {
      this.currentSelectedResembleRow = {
        visible: true,
        templateOid: row.codetemplateoid,
        codeClassifyOid: this.localCodeClassifyOid,
        rowOid: row.rowOid,
      };
    },
    submit() {
      const params = {
        classifyAttr: this.classifyAttr,
        improt: true,
        codeImprotSaveDatVOList: [
          {
            Clos: this.cloNamesList.map((item) => item.title),
            dataList: this.tab2Table.concat(this.selectedTab1Table),
            orderDTO: {
              codeClassifyOid: this.codeClassifyOid,
              templateOid: this.templateOid,
              secDTOList: [],
            },
          },
        ],
      };
      submitHistoryimport(params).then((res) => {
        console.log(res);
        if (res.data.code === 200) {
          this.$message.success(res.data.msg);
        } else {
          this.$message.error(res.data.msg);
        }
      });
    },
  },
  watch: {
    filterText(val) {
      this.$refs.tree.filter(val);
    },
  },
};
</script>

<style lang="scss" scoped>
.flex_box {
  display: flex;
  width: 1280px;
  .left {
    transition: all 0.5s;
    .isExpand_box {
      margin-bottom: 10px;
      text-align: right;
    }
    .filter_tree {
      margin-top: 15px;
      max-height: 400px;
      overflow-y: scroll;
    }
  }
  .right {
    margin-left: 20px;
    margin-top: 30px;
  }
}
</style>
